summaryrefslogtreecommitdiff
path: root/src/parser/smt2/sygus_input.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/parser/smt2/sygus_input.h')
-rw-r--r--src/parser/smt2/sygus_input.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/parser/smt2/sygus_input.h b/src/parser/smt2/sygus_input.h
index a0e3e81ef..39b161655 100644
--- a/src/parser/smt2/sygus_input.h
+++ b/src/parser/smt2/sygus_input.h
@@ -72,11 +72,11 @@ class SygusInput : public AntlrInput {
/**
* Parse an expression from the input. Returns a null
* <code>Expr</code> if there is no expression there to parse.
*
* @throws ParserException if an error is encountered during parsing.
*/
- Expr parseExpr() override;
+ api::Term parseExpr() override;
};/* class SygusInput */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -72,11 +72,11 @@ class SygusInput : public AntlrInput {
/**
* Parse an expression from the input. Returns a null
- * <code>Expr</code> if there is no expression there to parse.
+ * <code>api::Term</code> if there is no expression there to parse.
*
* @throws ParserException if an error is encountered during parsing.